# CMR Technical Reports Class

This repo contains a LaTeX class for CMR technical reports.

The class can be used to write technical reports in LaTeX or LyX.

CMR technical reports are a unique series of reports authored by yours truly.

---

## Files

This repo contains the LaTeX class to make technical reports,
as well as example LyX and LaTeX files that demosntrate usage
of the LaTeX class.

We cover what the different files are for.

### CMR Technical Report Class

* `cmrtechreport.cls` contains the LaTeX class definition for the technical
  report document class.

### Example Files

The `latex/` directory contains an example LaTeX file demonstrating how to
use the technical report class.

The `lyx/` directory contains an example LyX file demonstrating how to
use the technical report class.

---

## Installing and Using the Class

### Installing the LaTeX Class

To install the LaTeX class, use the Makefile:

```
make install-latex
```

The Makefile will create a new custom texmf directory at
`~/Library/texmf/`, and will install the LaTeX class at
`~/Library/texmf/tex/latex`. It will then run the `texhash`
command to update the TeX database of available classes.

The class consists of the base LaTeX class (.cls file) and
the images used in the report class (in the `*_figures` directory).
These are both copied to `~/Library/texmf/tex/latex/`.
Any relative references to images are resolved inside the texmf 
directory.

See [example_barebones/](example_barebones/Readme.md).

### Installing the LyX Layout

See [the example_lyx/ readme](example_lyx/Readme.md) for installation
instructions.

### Side Note: Where is the texmf directory?

To figure out where your TeX distribution's default texmf directory is located,
run the `texhash` command with no arguments. This will update the TeX database
with the contents of the texmf directory, and will print the location.

To use a custom texmf location, for example `~/Library/texmf`, create the
custom texmf directory, populate its contents, then pass the path to the
texhash command:

```
texhash ~/Library/texmf
```

Subdirectory schema:

* TeX-related files are installed to `~/Library/texmf/tex`
* LaTeX-related files are installed to `~/Library/texmf/tex/latex`
* LyX-related files are installed to `~/Library/texmf/tex/latex/lyx`

---

## Usage

To use the cmrtechreport class, specify it like so:

```
\documentclass[12pt]{cmrtechreport}
```

(This will look for a LaTeX class named `cmrtechreport` in the texmf dir.)

The user also needs to provide several input parameters in the LaTeX preamble
(the part before `\begin{document}`):

* `\title`
* `\author`
* `\date`
* `\reportid`
* `\version`
* `\url`
* `\orghierarchyfirst`
* `\orghierarchysecond`

The last two should list organizations or entities for the technical report.

* The first-level org hierarchy goes on the bottom footer.
* The second-level org hierarchy goes just below the title, date, and ID.

### Barebones Example

See [example_barebones/](example_barebones/Readme.md) dir.

### Bibliography Examples

See [example_natbib/](example_natbib/Readme.md) dir for an example of a
document using a "natural" bibliography (Last Name-Year).

See [example_plainbib/](example_plainbib/Readme.md) dir for an example of a
document using a "plain" bibliography (default style, numbered brackets,
sources listed in order of citation).

### LyX Example

See [example_lyx](example_lyx/Readme.md) dir for an example of how to use this
technical report class from a LyX document.
